/**
 * @file version.hpp
 * @brief Version information for the noLZSS library.
 *
 * This file defines the version constants for the noLZSS factorization library.
 * The version follows semantic versioning (MAJOR.MINOR.PATCH).
 */

#pragma once

namespace noLZSS {
    /** Major version number - incremented for breaking changes */
    static constexpr int VERSION_MAJOR = 0;
    /** Minor version number - incremented for new features */
    static constexpr int VERSION_MINOR = 1;
    /** Patch version number - incremented for bug fixes */
    static constexpr int VERSION_PATCH = 0;
}
